//=============================================================================
// GameTypeGrid.
//=============================================================================
class GameTypeGrid expands UWindowGrid;

var() localized string MapNameText,MapIndexTxt,AllGTypeIdx,AddToTxt;
var VotingReplicationInfo TheVotingHandler;
var int SelectedRowNow;
struct MListType
{
	var string MName;
	var byte IndexPos;
};
var MListType MapList[500];
var int NumMList;
var bool bHasBeenInit;
var AdminAMPD MapPullD;
var UWindowGridColumn GTypeColumns[10];

function Created() 
{
	Super.Created();
	RowHeight = 12;
	AddColumn(MapIndexTxt, 30);
	AddColumn(MapNameText, 100);
	AddColumn(AllGTypeIdx, 33);
}
function Tick(float Delta)
{
	if( TheVotingHandler==None )
	{
		ForEach GetPlayerOwner().AllActors(Class'VotingReplicationInfo',TheVotingHandler)
		{
			if( TheVotingHandler.Owner==GetPlayerOwner() )
				Break;
		}
		if( TheVotingHandler==None )
			Return;
	}
	if( TheVotingHandler.bMapListUpdated || !bHasBeenInit )
		UpdateMapList(TheVotingHandler);
	if( TheVotingHandler.bGameTypeListUpdated || !bHasBeenInit )
		UpdateGameTypeList(TheVotingHandler);
	if( !bHasBeenInit )
		bHasBeenInit = True;
}
function Paint(Canvas C, float X, float Y)
{
	DrawStretchedTexture(C, 0, 0, WinWidth, WinHeight, Texture'BlackTexture');
	Super.Paint(C,X,Y);
}
function PaintColumn(Canvas C, UWindowGridColumn Column, float MouseX, float MouseY) 
{
	local int Visible;
	local int Skipped;
	local int Y,i;
	local int TopMargin;
	local int BottomMargin;
	
	if(bShowHorizSB)
		BottomMargin = LookAndFeel.Size_ScrollbarWidth;
	else
		BottomMargin = 0;

	TopMargin = LookAndFeel.ColumnHeadingHeight;

	C.Font = Root.Fonts[F_Normal];
	Visible = int((WinHeight - (TopMargin + BottomMargin))/RowHeight);
	
	VertSB.SetRange(0, NumMList+1, Visible);
	TopRow = VertSB.Pos;

	Skipped = 0;

	Y = 1;
	i = 0;
	while( (Y < RowHeight + WinHeight - RowHeight - (TopMargin + BottomMargin)) && i<NumMList )
	{
		if(Skipped >= VertSB.Pos)
		{
			if( i==SelectedRowNow )
				Column.DrawStretchedTexture( C, 0, Y-1 + TopMargin, Column.WinWidth, RowHeight + 1, Texture'Highlight');
			switch(Column.ColumnNum)
			{
				case 0:
					Column.ClipText( C, 2, Y + TopMargin,string(i+1));
					break;
				case 1:
					Column.ClipText( C, 2, Y + TopMargin,MapList[i].MName);
					break;
				default:
					if( Column.ColumnNum==MapList[i].IndexPos )
						Column.ClipText( C, 2, Y + TopMargin,"X");
					break;
			}
			Y = Y + RowHeight;
		} 
		Skipped ++;
		i++;
	}
}

function RightClickRow(int Row, float X, float Y)
{
	local UBrowserInfoMenu Menu;
	local UWindowWindow U;
	local byte i,c;

	GetMouseXY(X,Y);
	if( MapPullD==None )
		MapPullD = AdminAMPD(CreateWindow(class'AdminAMPD', 0, 0, 160, 60));
	U = GetParent(class'UAdminClientW');
	MapPullD.WinLeft = X;
	MapPullD.WinTop = Y;
	MapPullD.ShowWindow();
	c = 3;
	For( i=0; i<10; i++ )
	{
		if( GTypeColumns[i]!=None )
		{
			c++;
			if( MapPullD.GTypeItems[i]!=None )
				MapPullD.GTypeItems[i].SetCaption(GTypeColumns[i].ColumnHeading);
			else
				MapPullD.GTypeItems[i] = MapPullD.AddGPullDown(AddToTxt@GTypeColumns[i].ColumnHeading, i);
		}
	}
	if( MapPullD.WinTop<=0 )
		MapPullD.WinTop = 0;
	else if( (MapPullD.WinTop+MapPullD.ItemHeight*c+3)>WinHeight )
		MapPullD.WinTop = WinHeight-MapPullD.ItemHeight*c-3;
}
function SortColumn(UWindowGridColumn Column) 
{
}
function SelectRow(int Row) 
{
	SelectedRowNow = Row;
}
function DoubleClickRow(int Row)
{
	SelectedRowNow = Row;
	RightClickRow(Row,0,0);
}

function UpdateMapList( VotingReplicationInfo Other )
{
	local string M[500];
	local int G[500],i;
	
	Other.GetActiveMapList(M,G);
	For( i=0; i<500; i++ )
	{
		if( M[i]=="" )
		{
			NumMList = i;
			Return;
		}
		MapList[i].MName = M[i];
		MapList[i].IndexPos = G[i]+3;
	}
	NumMList = 500;
}
function UpdateGameTypeList( VotingReplicationInfo Other )
{
	local string GN[10];
	local byte i;
	
	Other.GetActiveGameTypes(GN);
	For( i=0; i<10; i++ )
	{
		if( GN[i]=="" )
			Return;
		if( GTypeColumns[i]==None )
			GTypeColumns[i] = AddColumn(GN[i], 80);
		else GTypeColumns[i].ColumnHeading = GN[i];
	}
}
function RemoveFromMapList()
{
	TheVotingHandler.AdminRemoveMapList(MapList[SelectedRowNow].MName);
}
function SetNewGameIndex( int NewIndex )
{
	TheVotingHandler.AdminSetMapIndex(MapList[SelectedRowNow].MName,NewIndex);
}
function ForceMap()
{
	GetPlayerOwner().SwitchLevel(MapList[SelectedRowNow].MName);
}

defaultproperties
{
}
